Class: PhraseApp::Client
- Inherits:
-
Object
- Object
- PhraseApp::Client
- Defined in:
- lib/phraseapp-ruby.rb
Class Method Summary collapse
-
.authorization_create(params) ⇒ Object
Create a new authorization.
-
.authorization_delete(id) ⇒ Object
Delete an existing authorization.
-
.authorization_list(page, per_page) ⇒ Object
List all your authorizations.
-
.authorization_show(id) ⇒ Object
Get details on a single authorization.
-
.authorization_update(id, params) ⇒ Object
Update an existing authorization.
-
.blacklist_key_create(project_id, params) ⇒ Object
Create a new blacklisted key.
-
.blacklist_key_delete(project_id, id) ⇒ Object
Delete an existing blacklisted key.
-
.blacklist_key_show(project_id, id) ⇒ Object
Get details on a single blacklisted key for a given project.
-
.blacklist_key_update(project_id, id, params) ⇒ Object
Update an existing blacklisted key.
-
.blacklist_show(project_id, page, per_page) ⇒ Object
List all blacklisted keys for the given project.
-
.comment_create(project_id, key_id, params) ⇒ Object
Create a new comment for a key.
-
.comment_delete(project_id, key_id, id) ⇒ Object
Delete an existing comment.
-
.comment_list(project_id, key_id, page, per_page) ⇒ Object
List all comments for a key.
-
.comment_mark_check(project_id, key_id, id) ⇒ Object
Check if comment was marked as read.
-
.comment_mark_read(project_id, key_id, id) ⇒ Object
Mark a comment as read.
-
.comment_mark_unread(project_id, key_id, id) ⇒ Object
Mark a comment as unread.
-
.comment_show(project_id, key_id, id) ⇒ Object
Get details on a single comment.
-
.comment_update(project_id, key_id, id, params) ⇒ Object
Update an existing comment.
-
.formats_list(page, per_page) ⇒ Object
Get a handy list of all localization file formats supported in PhraseApp.
-
.key_create(project_id, params) ⇒ Object
Create a new key.
-
.key_delete(project_id, id) ⇒ Object
Delete an existing key.
-
.key_list(project_id, page, per_page, params) ⇒ Object
List all keys for the given project.
-
.key_show(project_id, id) ⇒ Object
Get details on a single key for a given project.
-
.key_update(project_id, id, params) ⇒ Object
Update an existing key.
-
.locale_create(project_id, params) ⇒ Object
Create a new locale.
-
.locale_delete(project_id, id) ⇒ Object
Delete an existing locale.
-
.locale_download(project_id, id, params) ⇒ Object
Download a locale in a specific file format.
-
.locale_list(project_id, page, per_page) ⇒ Object
List all locales for the given project.
-
.locale_show(project_id, id) ⇒ Object
Get details on a single locale for a given project.
-
.locale_update(project_id, id, params) ⇒ Object
Update an existing locale.
-
.order_confirm(project_id, id) ⇒ Object
Confirm an existing order.
-
.order_create(project_id, params) ⇒ Object
Create a new order.
-
.order_delete(project_id, id) ⇒ Object
Cancel an existing order.
-
.order_list(project_id, page, per_page) ⇒ Object
List all orders for the given project.
-
.order_show(project_id, id) ⇒ Object
Get details on a single order.
-
.project_create(params) ⇒ Object
Create a new project.
-
.project_delete(id) ⇒ Object
Delete an existing project.
-
.project_list(page, per_page) ⇒ Object
List all projects the current user has access to.
-
.project_show(id) ⇒ Object
Get details on a single project.
-
.project_update(id, params) ⇒ Object
Update an existing project.
-
.show_user ⇒ Object
Show details for current User.
-
.styleguide_create(project_id, params) ⇒ Object
Create a new style guide.
-
.styleguide_delete(project_id, id) ⇒ Object
Delete an existing style guide.
-
.styleguide_list(project_id, page, per_page) ⇒ Object
List all styleguides for the given project.
-
.styleguide_show(project_id, id) ⇒ Object
Get details on a single style guide.
-
.styleguide_update(project_id, id, params) ⇒ Object
Update an existing style guide.
-
.tag_create(project_id, params) ⇒ Object
Create a new tag.
-
.tag_delete(project_id, name) ⇒ Object
Delete an existing tag.
-
.tag_list(project_id, page, per_page) ⇒ Object
List all tags for the given project.
-
.tag_show(project_id, name) ⇒ Object
Get details and progress information on a single tag for a given project.
-
.translation_create(project_id, params) ⇒ Object
Create a translation.
-
.translation_list_all(project_id, page, per_page, params) ⇒ Object
List translations for the given project.
-
.translation_list_key(project_id, key_id, page, per_page, params) ⇒ Object
List translations for a specific key.
-
.translation_list_locale(project_id, locale_id, page, per_page, params) ⇒ Object
List translations for a specific locale.
-
.translation_show(project_id, id) ⇒ Object
Get details on a single translation.
-
.translation_update(project_id, id, params) ⇒ Object
Update an existing translation.
-
.upload_create(project_id, params) ⇒ Object
Upload a new file to your project.
-
.upload_show(project_id, id) ⇒ Object
View details and summary for a single upload.
-
.version_list(project_id, translation_id, page, per_page) ⇒ Object
List all versions for the given translation.
-
.version_show(project_id, translation_id, id) ⇒ Object
Get details on a single version.
Class Method Details
.authorization_create(params) ⇒ Object
Create a new authorization.
810 811 812 813 814 815 816 817 818 819 820 821 822 823 824 825 826 827 |
# File 'lib/phraseapp-ruby.rb', line 810 def self.(params) path = sprintf("/v2/authorizations") data_hash = {} post_body = nil data_hash = params.to_h err = params.validate if err != nil return nil, err end reqHelper = PhraseApp::RequestHelper.new(data_hash, post_body) rc, err = PhraseApp.send_request("POST", path, reqHelper.ctype, reqHelper.body, 201) if err != nil return nil, err end return PhraseApp::AuthorizationWithToken.new(JSON.load(rc.body)), err end |
.authorization_delete(id) ⇒ Object
Delete an existing authorization. Please note that this will revoke access for that token, so API calls using that token will stop working.
830 831 832 833 834 835 836 837 838 839 840 841 842 |
# File 'lib/phraseapp-ruby.rb', line 830 def self.(id) path = sprintf("/v2/authorizations/%s", id) data_hash = {} post_body = nil reqHelper = PhraseApp::RequestHelper.new(data_hash, post_body) rc, err = PhraseApp.send_request("DELETE", path, reqHelper.ctype, reqHelper.body, 204) if err != nil return nil, err end return err end |
.authorization_list(page, per_page) ⇒ Object
List all your authorizations.
845 846 847 848 849 850 851 852 853 854 855 856 857 |
# File 'lib/phraseapp-ruby.rb', line 845 def self.(page, per_page) path = sprintf("/v2/authorizations") data_hash = {} post_body = nil reqHelper = PhraseApp::RequestHelper.new(data_hash, post_body) rc, err = PhraseApp.send_request_paginated("GET", path, reqHelper.ctype, reqHelper.body, 200, page, per_page) if err != nil return nil, err end return JSON.load(rc.body).map { |item| PhraseApp::Authorization.new(item) }, err end |
.authorization_show(id) ⇒ Object
Get details on a single authorization.
860 861 862 863 864 865 866 867 868 869 870 871 872 |
# File 'lib/phraseapp-ruby.rb', line 860 def self.(id) path = sprintf("/v2/authorizations/%s", id) data_hash = {} post_body = nil reqHelper = PhraseApp::RequestHelper.new(data_hash, post_body) rc, err = PhraseApp.send_request("GET", path, reqHelper.ctype, reqHelper.body, 200) if err != nil return nil, err end return PhraseApp::Authorization.new(JSON.load(rc.body)), err end |
.authorization_update(id, params) ⇒ Object
Update an existing authorization.
875 876 877 878 879 880 881 882 883 884 885 886 887 888 889 890 891 892 |
# File 'lib/phraseapp-ruby.rb', line 875 def self.(id, params) path = sprintf("/v2/authorizations/%s", id) data_hash = {} post_body = nil data_hash = params.to_h err = params.validate if err != nil return nil, err end reqHelper = PhraseApp::RequestHelper.new(data_hash, post_body) rc, err = PhraseApp.send_request("PATCH", path, reqHelper.ctype, reqHelper.body, 200) if err != nil return nil, err end return PhraseApp::Authorization.new(JSON.load(rc.body)), err end |
.blacklist_key_create(project_id, params) ⇒ Object
Create a new blacklisted key.
895 896 897 898 899 900 901 902 903 904 905 906 907 908 909 910 911 912 |
# File 'lib/phraseapp-ruby.rb', line 895 def self.blacklist_key_create(project_id, params) path = sprintf("/v2/projects/%s/blacklisted_keys", project_id) data_hash = {} post_body = nil data_hash = params.to_h err = params.validate if err != nil return nil, err end reqHelper = PhraseApp::RequestHelper.new(data_hash, post_body) rc, err = PhraseApp.send_request("POST", path, reqHelper.ctype, reqHelper.body, 201) if err != nil return nil, err end return PhraseApp::BlacklistedKey.new(JSON.load(rc.body)), err end |
.blacklist_key_delete(project_id, id) ⇒ Object
Delete an existing blacklisted key.
915 916 917 918 919 920 921 922 923 924 925 926 927 |
# File 'lib/phraseapp-ruby.rb', line 915 def self.blacklist_key_delete(project_id, id) path = sprintf("/v2/projects/%s/blacklisted_keys/%s", project_id, id) data_hash = {} post_body = nil reqHelper = PhraseApp::RequestHelper.new(data_hash, post_body) rc, err = PhraseApp.send_request("DELETE", path, reqHelper.ctype, reqHelper.body, 204) if err != nil return nil, err end return err end |
.blacklist_key_show(project_id, id) ⇒ Object
Get details on a single blacklisted key for a given project.
930 931 932 933 934 935 936 937 938 939 940 941 942 |
# File 'lib/phraseapp-ruby.rb', line 930 def self.blacklist_key_show(project_id, id) path = sprintf("/v2/projects/%s/blacklisted_keys/%s", project_id, id) data_hash = {} post_body = nil reqHelper = PhraseApp::RequestHelper.new(data_hash, post_body) rc, err = PhraseApp.send_request("GET", path, reqHelper.ctype, reqHelper.body, 200) if err != nil return nil, err end return PhraseApp::BlacklistedKey.new(JSON.load(rc.body)), err end |
.blacklist_key_update(project_id, id, params) ⇒ Object
Update an existing blacklisted key.
945 946 947 948 949 950 951 952 953 954 955 956 957 958 959 960 961 962 |
# File 'lib/phraseapp-ruby.rb', line 945 def self.blacklist_key_update(project_id, id, params) path = sprintf("/v2/projects/%s/blacklisted_keys/%s", project_id, id) data_hash = {} post_body = nil data_hash = params.to_h err = params.validate if err != nil return nil, err end reqHelper = PhraseApp::RequestHelper.new(data_hash, post_body) rc, err = PhraseApp.send_request("PATCH", path, reqHelper.ctype, reqHelper.body, 200) if err != nil return nil, err end return PhraseApp::BlacklistedKey.new(JSON.load(rc.body)), err end |
.blacklist_show(project_id, page, per_page) ⇒ Object
List all blacklisted keys for the given project.
965 966 967 968 969 970 971 972 973 974 975 976 977 |
# File 'lib/phraseapp-ruby.rb', line 965 def self.blacklist_show(project_id, page, per_page) path = sprintf("/v2/projects/%s/blacklisted_keys", project_id) data_hash = {} post_body = nil reqHelper = PhraseApp::RequestHelper.new(data_hash, post_body) rc, err = PhraseApp.send_request_paginated("GET", path, reqHelper.ctype, reqHelper.body, 200, page, per_page) if err != nil return nil, err end return JSON.load(rc.body).map { |item| PhraseApp::BlacklistedKey.new(item) }, err end |
.comment_create(project_id, key_id, params) ⇒ Object
Create a new comment for a key.
980 981 982 983 984 985 986 987 988 989 990 991 992 993 994 995 996 997 |
# File 'lib/phraseapp-ruby.rb', line 980 def self.comment_create(project_id, key_id, params) path = sprintf("/v2/projects/%s/keys/%s/comments", project_id, key_id) data_hash = {} post_body = nil data_hash = params.to_h err = params.validate if err != nil return nil, err end reqHelper = PhraseApp::RequestHelper.new(data_hash, post_body) rc, err = PhraseApp.send_request("POST", path, reqHelper.ctype, reqHelper.body, 201) if err != nil return nil, err end return PhraseApp::Comment.new(JSON.load(rc.body)), err end |
.comment_delete(project_id, key_id, id) ⇒ Object
Delete an existing comment.
1000 1001 1002 1003 1004 1005 1006 1007 1008 1009 1010 1011 1012 |
# File 'lib/phraseapp-ruby.rb', line 1000 def self.comment_delete(project_id, key_id, id) path = sprintf("/v2/projects/%s/keys/%s/comments/%s", project_id, key_id, id) data_hash = {} post_body = nil reqHelper = PhraseApp::RequestHelper.new(data_hash, post_body) rc, err = PhraseApp.send_request("DELETE", path, reqHelper.ctype, reqHelper.body, 204) if err != nil return nil, err end return err end |
.comment_list(project_id, key_id, page, per_page) ⇒ Object
List all comments for a key.
1015 1016 1017 1018 1019 1020 1021 1022 1023 1024 1025 1026 1027 |
# File 'lib/phraseapp-ruby.rb', line 1015 def self.comment_list(project_id, key_id, page, per_page) path = sprintf("/v2/projects/%s/keys/%s/comments", project_id, key_id) data_hash = {} post_body = nil reqHelper = PhraseApp::RequestHelper.new(data_hash, post_body) rc, err = PhraseApp.send_request_paginated("GET", path, reqHelper.ctype, reqHelper.body, 200, page, per_page) if err != nil return nil, err end return JSON.load(rc.body).map { |item| PhraseApp::Comment.new(item) }, err end |
.comment_mark_check(project_id, key_id, id) ⇒ Object
Check if comment was marked as read. Returns 204 if read, 404 if unread.
1030 1031 1032 1033 1034 1035 1036 1037 1038 1039 1040 1041 1042 |
# File 'lib/phraseapp-ruby.rb', line 1030 def self.comment_mark_check(project_id, key_id, id) path = sprintf("/v2/projects/%s/keys/%s/comments/%s/read", project_id, key_id, id) data_hash = {} post_body = nil reqHelper = PhraseApp::RequestHelper.new(data_hash, post_body) rc, err = PhraseApp.send_request("GET", path, reqHelper.ctype, reqHelper.body, 204) if err != nil return nil, err end return err end |
.comment_mark_read(project_id, key_id, id) ⇒ Object
Mark a comment as read
1045 1046 1047 1048 1049 1050 1051 1052 1053 1054 1055 1056 1057 |
# File 'lib/phraseapp-ruby.rb', line 1045 def self.comment_mark_read(project_id, key_id, id) path = sprintf("/v2/projects/%s/keys/%s/comments/%s/read", project_id, key_id, id) data_hash = {} post_body = nil reqHelper = PhraseApp::RequestHelper.new(data_hash, post_body) rc, err = PhraseApp.send_request("PUT", path, reqHelper.ctype, reqHelper.body, 204) if err != nil return nil, err end return err end |
.comment_mark_unread(project_id, key_id, id) ⇒ Object
Mark a comment as unread
1060 1061 1062 1063 1064 1065 1066 1067 1068 1069 1070 1071 1072 |
# File 'lib/phraseapp-ruby.rb', line 1060 def self.comment_mark_unread(project_id, key_id, id) path = sprintf("/v2/projects/%s/keys/%s/comments/%s/read", project_id, key_id, id) data_hash = {} post_body = nil reqHelper = PhraseApp::RequestHelper.new(data_hash, post_body) rc, err = PhraseApp.send_request("DELETE", path, reqHelper.ctype, reqHelper.body, 204) if err != nil return nil, err end return err end |
.comment_show(project_id, key_id, id) ⇒ Object
Get details on a single comment.
1075 1076 1077 1078 1079 1080 1081 1082 1083 1084 1085 1086 1087 |
# File 'lib/phraseapp-ruby.rb', line 1075 def self.comment_show(project_id, key_id, id) path = sprintf("/v2/projects/%s/keys/%s/comments/%s", project_id, key_id, id) data_hash = {} post_body = nil reqHelper = PhraseApp::RequestHelper.new(data_hash, post_body) rc, err = PhraseApp.send_request("GET", path, reqHelper.ctype, reqHelper.body, 200) if err != nil return nil, err end return PhraseApp::Comment.new(JSON.load(rc.body)), err end |
.comment_update(project_id, key_id, id, params) ⇒ Object
Update an existing comment.
1090 1091 1092 1093 1094 1095 1096 1097 1098 1099 1100 1101 1102 1103 1104 1105 1106 1107 |
# File 'lib/phraseapp-ruby.rb', line 1090 def self.comment_update(project_id, key_id, id, params) path = sprintf("/v2/projects/%s/keys/%s/comments/%s", project_id, key_id, id) data_hash = {} post_body = nil data_hash = params.to_h err = params.validate if err != nil return nil, err end reqHelper = PhraseApp::RequestHelper.new(data_hash, post_body) rc, err = PhraseApp.send_request("PATCH", path, reqHelper.ctype, reqHelper.body, 200) if err != nil return nil, err end return PhraseApp::Comment.new(JSON.load(rc.body)), err end |
.formats_list(page, per_page) ⇒ Object
Get a handy list of all localization file formats supported in PhraseApp.
1110 1111 1112 1113 1114 1115 1116 1117 1118 1119 1120 1121 1122 |
# File 'lib/phraseapp-ruby.rb', line 1110 def self.formats_list(page, per_page) path = sprintf("/v2/formats") data_hash = {} post_body = nil reqHelper = PhraseApp::RequestHelper.new(data_hash, post_body) rc, err = PhraseApp.send_request_paginated("GET", path, reqHelper.ctype, reqHelper.body, 200, page, per_page) if err != nil return nil, err end return JSON.load(rc.body).map { |item| PhraseApp::Format.new(item) }, err end |
.key_create(project_id, params) ⇒ Object
Create a new key.
1125 1126 1127 1128 1129 1130 1131 1132 1133 1134 1135 1136 1137 1138 1139 1140 1141 1142 1143 1144 1145 1146 1147 1148 1149 1150 1151 1152 1153 1154 1155 1156 1157 1158 1159 1160 1161 1162 1163 1164 1165 1166 1167 1168 1169 1170 1171 1172 1173 1174 1175 1176 1177 1178 1179 1180 1181 1182 1183 1184 1185 1186 1187 1188 1189 1190 1191 1192 1193 1194 1195 1196 |
# File 'lib/phraseapp-ruby.rb', line 1125 def self.key_create(project_id, params) path = sprintf("/v2/projects/%s/keys", project_id) data_hash = {} post_body = nil if params.data_type != nil data_hash["data_type"] = params.data_type end if params.description != nil data_hash["description"] = params.description end if params.format_value_type != nil data_hash["format_value_type"] = params.format_value_type end if params.max_characters_allowed != nil data_hash["max_characters_allowed"] = params.max_characters_allowed.to_i end if params.name != nil data_hash["name"] = params.name end if params.name_plural != nil data_hash["name_plural"] = params.name_plural end if params.original_file != nil data_hash["original_file"] = params.original_file end if params.plural != nil data_hash["plural"] = (params.plural == "true") end if params.remove_screenshot != nil data_hash["remove_screenshot"] = (params.remove_screenshot == "true") end if params.screenshot != nil post_body = [] post_body << "--#{PhraseApp::MULTIPART_BOUNDARY}\r\n" post_body << "Content-Disposition: form-data; name=\"screenshot\"; filename=\"#{File.basename(params.screenshot )}\"\r\n" post_body << "Content-Type: text/plain\r\n" post_body << "\r\n" post_body << File.read(params.screenshot) post_body << "\r\n" end if params. != nil data_hash["tags"] = params. end if params.unformatted != nil data_hash["unformatted"] = (params.unformatted == "true") end if params.xml_space_preserve != nil data_hash["xml_space_preserve"] = (params.xml_space_preserve == "true") end reqHelper = PhraseApp::RequestHelper.new(data_hash, post_body) rc, err = PhraseApp.send_request("POST", path, reqHelper.ctype, reqHelper.body, 201) if err != nil return nil, err end return PhraseApp::TranslationKeyDetails.new(JSON.load(rc.body)), err end |
.key_delete(project_id, id) ⇒ Object
Delete an existing key.
1199 1200 1201 1202 1203 1204 1205 1206 1207 1208 1209 1210 1211 |
# File 'lib/phraseapp-ruby.rb', line 1199 def self.key_delete(project_id, id) path = sprintf("/v2/projects/%s/keys/%s", project_id, id) data_hash = {} post_body = nil reqHelper = PhraseApp::RequestHelper.new(data_hash, post_body) rc, err = PhraseApp.send_request("DELETE", path, reqHelper.ctype, reqHelper.body, 204) if err != nil return nil, err end return err end |
.key_list(project_id, page, per_page, params) ⇒ Object
List all keys for the given project.
1214 1215 1216 1217 1218 1219 1220 1221 1222 1223 1224 1225 1226 1227 1228 1229 1230 1231 |
# File 'lib/phraseapp-ruby.rb', line 1214 def self.key_list(project_id, page, per_page, params) path = sprintf("/v2/projects/%s/keys", project_id) data_hash = {} post_body = nil data_hash = params.to_h err = params.validate if err != nil return nil, err end reqHelper = PhraseApp::RequestHelper.new(data_hash, post_body) rc, err = PhraseApp.send_request_paginated("GET", path, reqHelper.ctype, reqHelper.body, 200, page, per_page) if err != nil return nil, err end return JSON.load(rc.body).map { |item| PhraseApp::TranslationKey.new(item) }, err end |
.key_show(project_id, id) ⇒ Object
Get details on a single key for a given project.
1234 1235 1236 1237 1238 1239 1240 1241 1242 1243 1244 1245 1246 |
# File 'lib/phraseapp-ruby.rb', line 1234 def self.key_show(project_id, id) path = sprintf("/v2/projects/%s/keys/%s", project_id, id) data_hash = {} post_body = nil reqHelper = PhraseApp::RequestHelper.new(data_hash, post_body) rc, err = PhraseApp.send_request("GET", path, reqHelper.ctype, reqHelper.body, 200) if err != nil return nil, err end return PhraseApp::TranslationKeyDetails.new(JSON.load(rc.body)), err end |
.key_update(project_id, id, params) ⇒ Object
Update an existing key.
1249 1250 1251 1252 1253 1254 1255 1256 1257 1258 1259 1260 1261 1262 1263 1264 1265 1266 1267 1268 1269 1270 1271 1272 1273 1274 1275 1276 1277 1278 1279 1280 1281 1282 1283 1284 1285 1286 1287 1288 1289 1290 1291 1292 1293 1294 1295 1296 1297 1298 1299 1300 1301 1302 1303 1304 1305 1306 1307 1308 1309 1310 1311 1312 1313 1314 1315 1316 1317 1318 1319 1320 |
# File 'lib/phraseapp-ruby.rb', line 1249 def self.key_update(project_id, id, params) path = sprintf("/v2/projects/%s/keys/%s", project_id, id) data_hash = {} post_body = nil if params.data_type != nil data_hash["data_type"] = params.data_type end if params.description != nil data_hash["description"] = params.description end if params.format_value_type != nil data_hash["format_value_type"] = params.format_value_type end if params.max_characters_allowed != nil data_hash["max_characters_allowed"] = params.max_characters_allowed.to_i end if params.name != nil data_hash["name"] = params.name end if params.name_plural != nil data_hash["name_plural"] = params.name_plural end if params.original_file != nil data_hash["original_file"] = params.original_file end if params.plural != nil data_hash["plural"] = (params.plural == "true") end if params.remove_screenshot != nil data_hash["remove_screenshot"] = (params.remove_screenshot == "true") end if params.screenshot != nil post_body = [] post_body << "--#{PhraseApp::MULTIPART_BOUNDARY}\r\n" post_body << "Content-Disposition: form-data; name=\"screenshot\"; filename=\"#{File.basename(params.screenshot )}\"\r\n" post_body << "Content-Type: text/plain\r\n" post_body << "\r\n" post_body << File.read(params.screenshot) post_body << "\r\n" end if params. != nil data_hash["tags"] = params. end if params.unformatted != nil data_hash["unformatted"] = (params.unformatted == "true") end if params.xml_space_preserve != nil data_hash["xml_space_preserve"] = (params.xml_space_preserve == "true") end reqHelper = PhraseApp::RequestHelper.new(data_hash, post_body) rc, err = PhraseApp.send_request("PATCH", path, reqHelper.ctype, reqHelper.body, 200) if err != nil return nil, err end return PhraseApp::TranslationKeyDetails.new(JSON.load(rc.body)), err end |
.locale_create(project_id, params) ⇒ Object
Create a new locale.
1323 1324 1325 1326 1327 1328 1329 1330 1331 1332 1333 1334 1335 1336 1337 1338 1339 1340 |
# File 'lib/phraseapp-ruby.rb', line 1323 def self.locale_create(project_id, params) path = sprintf("/v2/projects/%s/locales", project_id) data_hash = {} post_body = nil data_hash = params.to_h err = params.validate if err != nil return nil, err end reqHelper = PhraseApp::RequestHelper.new(data_hash, post_body) rc, err = PhraseApp.send_request("POST", path, reqHelper.ctype, reqHelper.body, 201) if err != nil return nil, err end return PhraseApp::LocaleDetails.new(JSON.load(rc.body)), err end |
.locale_delete(project_id, id) ⇒ Object
Delete an existing locale.
1343 1344 1345 1346 1347 1348 1349 1350 1351 1352 1353 1354 1355 |
# File 'lib/phraseapp-ruby.rb', line 1343 def self.locale_delete(project_id, id) path = sprintf("/v2/projects/%s/locales/%s", project_id, id) data_hash = {} post_body = nil reqHelper = PhraseApp::RequestHelper.new(data_hash, post_body) rc, err = PhraseApp.send_request("DELETE", path, reqHelper.ctype, reqHelper.body, 204) if err != nil return nil, err end return err end |
.locale_download(project_id, id, params) ⇒ Object
Download a locale in a specific file format.
1358 1359 1360 1361 1362 1363 1364 1365 1366 1367 1368 1369 1370 1371 1372 1373 1374 1375 |
# File 'lib/phraseapp-ruby.rb', line 1358 def self.locale_download(project_id, id, params) path = sprintf("/v2/projects/%s/locales/%s/download", project_id, id) data_hash = {} post_body = nil data_hash = params.to_h err = params.validate if err != nil return nil, err end reqHelper = PhraseApp::RequestHelper.new(data_hash, post_body) rc, err = PhraseApp.send_request("GET", path, reqHelper.ctype, reqHelper.body, 200) if err != nil return nil, err end return rc.body return err end |
.locale_list(project_id, page, per_page) ⇒ Object
List all locales for the given project.
1378 1379 1380 1381 1382 1383 1384 1385 1386 1387 1388 1389 1390 |
# File 'lib/phraseapp-ruby.rb', line 1378 def self.locale_list(project_id, page, per_page) path = sprintf("/v2/projects/%s/locales", project_id) data_hash = {} post_body = nil reqHelper = PhraseApp::RequestHelper.new(data_hash, post_body) rc, err = PhraseApp.send_request_paginated("GET", path, reqHelper.ctype, reqHelper.body, 200, page, per_page) if err != nil return nil, err end return JSON.load(rc.body).map { |item| PhraseApp::Locale.new(item) }, err end |
.locale_show(project_id, id) ⇒ Object
Get details on a single locale for a given project.
1393 1394 1395 1396 1397 1398 1399 1400 1401 1402 1403 1404 1405 |
# File 'lib/phraseapp-ruby.rb', line 1393 def self.locale_show(project_id, id) path = sprintf("/v2/projects/%s/locales/%s", project_id, id) data_hash = {} post_body = nil reqHelper = PhraseApp::RequestHelper.new(data_hash, post_body) rc, err = PhraseApp.send_request("GET", path, reqHelper.ctype, reqHelper.body, 200) if err != nil return nil, err end return PhraseApp::LocaleDetails.new(JSON.load(rc.body)), err end |
.locale_update(project_id, id, params) ⇒ Object
Update an existing locale.
1408 1409 1410 1411 1412 1413 1414 1415 1416 1417 1418 1419 1420 1421 1422 1423 1424 1425 |
# File 'lib/phraseapp-ruby.rb', line 1408 def self.locale_update(project_id, id, params) path = sprintf("/v2/projects/%s/locales/%s", project_id, id) data_hash = {} post_body = nil data_hash = params.to_h err = params.validate if err != nil return nil, err end reqHelper = PhraseApp::RequestHelper.new(data_hash, post_body) rc, err = PhraseApp.send_request("PATCH", path, reqHelper.ctype, reqHelper.body, 200) if err != nil return nil, err end return PhraseApp::LocaleDetails.new(JSON.load(rc.body)), err end |
.order_confirm(project_id, id) ⇒ Object
Confirm an existing order. Sends the order to the language service provider for processing. Please note that your access token must include the orders.create scope to confirm orders.
1428 1429 1430 1431 1432 1433 1434 1435 1436 1437 1438 1439 1440 |
# File 'lib/phraseapp-ruby.rb', line 1428 def self.order_confirm(project_id, id) path = sprintf("/v2/projects/%s/orders/%s/confirm", project_id, id) data_hash = {} post_body = nil reqHelper = PhraseApp::RequestHelper.new(data_hash, post_body) rc, err = PhraseApp.send_request("PATCH", path, reqHelper.ctype, reqHelper.body, 200) if err != nil return nil, err end return PhraseApp::TranslationOrder.new(JSON.load(rc.body)), err end |
.order_create(project_id, params) ⇒ Object
Create a new order. Please note that your access token must include the orders.create scope to create orders.
1443 1444 1445 1446 1447 1448 1449 1450 1451 1452 1453 1454 1455 1456 1457 1458 1459 1460 |
# File 'lib/phraseapp-ruby.rb', line 1443 def self.order_create(project_id, params) path = sprintf("/v2/projects/%s/orders", project_id) data_hash = {} post_body = nil data_hash = params.to_h err = params.validate if err != nil return nil, err end reqHelper = PhraseApp::RequestHelper.new(data_hash, post_body) rc, err = PhraseApp.send_request("POST", path, reqHelper.ctype, reqHelper.body, 201) if err != nil return nil, err end return PhraseApp::TranslationOrder.new(JSON.load(rc.body)), err end |
.order_delete(project_id, id) ⇒ Object
Cancel an existing order. Must not yet be confirmed.
1463 1464 1465 1466 1467 1468 1469 1470 1471 1472 1473 1474 1475 |
# File 'lib/phraseapp-ruby.rb', line 1463 def self.order_delete(project_id, id) path = sprintf("/v2/projects/%s/orders/%s", project_id, id) data_hash = {} post_body = nil reqHelper = PhraseApp::RequestHelper.new(data_hash, post_body) rc, err = PhraseApp.send_request("DELETE", path, reqHelper.ctype, reqHelper.body, 204) if err != nil return nil, err end return err end |
.order_list(project_id, page, per_page) ⇒ Object
List all orders for the given project.
1478 1479 1480 1481 1482 1483 1484 1485 1486 1487 1488 1489 1490 |
# File 'lib/phraseapp-ruby.rb', line 1478 def self.order_list(project_id, page, per_page) path = sprintf("/v2/projects/%s/orders", project_id) data_hash = {} post_body = nil reqHelper = PhraseApp::RequestHelper.new(data_hash, post_body) rc, err = PhraseApp.send_request_paginated("GET", path, reqHelper.ctype, reqHelper.body, 200, page, per_page) if err != nil return nil, err end return JSON.load(rc.body).map { |item| PhraseApp::TranslationOrder.new(item) }, err end |
.order_show(project_id, id) ⇒ Object
Get details on a single order.
1493 1494 1495 1496 1497 1498 1499 1500 1501 1502 1503 1504 1505 |
# File 'lib/phraseapp-ruby.rb', line 1493 def self.order_show(project_id, id) path = sprintf("/v2/projects/%s/orders/%s", project_id, id) data_hash = {} post_body = nil reqHelper = PhraseApp::RequestHelper.new(data_hash, post_body) rc, err = PhraseApp.send_request("GET", path, reqHelper.ctype, reqHelper.body, 200) if err != nil return nil, err end return PhraseApp::TranslationOrder.new(JSON.load(rc.body)), err end |
.project_create(params) ⇒ Object
Create a new project.
1508 1509 1510 1511 1512 1513 1514 1515 1516 1517 1518 1519 1520 1521 1522 1523 1524 1525 |
# File 'lib/phraseapp-ruby.rb', line 1508 def self.project_create(params) path = sprintf("/v2/projects") data_hash = {} post_body = nil data_hash = params.to_h err = params.validate if err != nil return nil, err end reqHelper = PhraseApp::RequestHelper.new(data_hash, post_body) rc, err = PhraseApp.send_request("POST", path, reqHelper.ctype, reqHelper.body, 201) if err != nil return nil, err end return PhraseApp::ProjectDetails.new(JSON.load(rc.body)), err end |
.project_delete(id) ⇒ Object
Delete an existing project.
1528 1529 1530 1531 1532 1533 1534 1535 1536 1537 1538 1539 1540 |
# File 'lib/phraseapp-ruby.rb', line 1528 def self.project_delete(id) path = sprintf("/v2/projects/%s", id) data_hash = {} post_body = nil reqHelper = PhraseApp::RequestHelper.new(data_hash, post_body) rc, err = PhraseApp.send_request("DELETE", path, reqHelper.ctype, reqHelper.body, 204) if err != nil return nil, err end return err end |
.project_list(page, per_page) ⇒ Object
List all projects the current user has access to.
1543 1544 1545 1546 1547 1548 1549 1550 1551 1552 1553 1554 1555 |
# File 'lib/phraseapp-ruby.rb', line 1543 def self.project_list(page, per_page) path = sprintf("/v2/projects") data_hash = {} post_body = nil reqHelper = PhraseApp::RequestHelper.new(data_hash, post_body) rc, err = PhraseApp.send_request_paginated("GET", path, reqHelper.ctype, reqHelper.body, 200, page, per_page) if err != nil return nil, err end return JSON.load(rc.body).map { |item| PhraseApp::Project.new(item) }, err end |
.project_show(id) ⇒ Object
Get details on a single project.
1558 1559 1560 1561 1562 1563 1564 1565 1566 1567 1568 1569 1570 |
# File 'lib/phraseapp-ruby.rb', line 1558 def self.project_show(id) path = sprintf("/v2/projects/%s", id) data_hash = {} post_body = nil reqHelper = PhraseApp::RequestHelper.new(data_hash, post_body) rc, err = PhraseApp.send_request("GET", path, reqHelper.ctype, reqHelper.body, 200) if err != nil return nil, err end return PhraseApp::ProjectDetails.new(JSON.load(rc.body)), err end |
.project_update(id, params) ⇒ Object
Update an existing project.
1573 1574 1575 1576 1577 1578 1579 1580 1581 1582 1583 1584 1585 1586 1587 1588 1589 1590 |
# File 'lib/phraseapp-ruby.rb', line 1573 def self.project_update(id, params) path = sprintf("/v2/projects/%s", id) data_hash = {} post_body = nil data_hash = params.to_h err = params.validate if err != nil return nil, err end reqHelper = PhraseApp::RequestHelper.new(data_hash, post_body) rc, err = PhraseApp.send_request("PATCH", path, reqHelper.ctype, reqHelper.body, 200) if err != nil return nil, err end return PhraseApp::ProjectDetails.new(JSON.load(rc.body)), err end |
.show_user ⇒ Object
Show details for current User.
1593 1594 1595 1596 1597 1598 1599 1600 1601 1602 1603 1604 1605 |
# File 'lib/phraseapp-ruby.rb', line 1593 def self.show_user() path = sprintf("/v2/user") data_hash = {} post_body = nil reqHelper = PhraseApp::RequestHelper.new(data_hash, post_body) rc, err = PhraseApp.send_request("GET", path, reqHelper.ctype, reqHelper.body, 200) if err != nil return nil, err end return PhraseApp::User.new(JSON.load(rc.body)), err end |
.styleguide_create(project_id, params) ⇒ Object
Create a new style guide.
1608 1609 1610 1611 1612 1613 1614 1615 1616 1617 1618 1619 1620 1621 1622 1623 1624 1625 |
# File 'lib/phraseapp-ruby.rb', line 1608 def self.styleguide_create(project_id, params) path = sprintf("/v2/projects/%s/styleguides", project_id) data_hash = {} post_body = nil data_hash = params.to_h err = params.validate if err != nil return nil, err end reqHelper = PhraseApp::RequestHelper.new(data_hash, post_body) rc, err = PhraseApp.send_request("POST", path, reqHelper.ctype, reqHelper.body, 201) if err != nil return nil, err end return PhraseApp::StyleguideDetails.new(JSON.load(rc.body)), err end |
.styleguide_delete(project_id, id) ⇒ Object
Delete an existing style guide.
1628 1629 1630 1631 1632 1633 1634 1635 1636 1637 1638 1639 1640 |
# File 'lib/phraseapp-ruby.rb', line 1628 def self.styleguide_delete(project_id, id) path = sprintf("/v2/projects/%s/styleguides/%s", project_id, id) data_hash = {} post_body = nil reqHelper = PhraseApp::RequestHelper.new(data_hash, post_body) rc, err = PhraseApp.send_request("DELETE", path, reqHelper.ctype, reqHelper.body, 204) if err != nil return nil, err end return err end |
.styleguide_list(project_id, page, per_page) ⇒ Object
List all styleguides for the given project.
1643 1644 1645 1646 1647 1648 1649 1650 1651 1652 1653 1654 1655 |
# File 'lib/phraseapp-ruby.rb', line 1643 def self.styleguide_list(project_id, page, per_page) path = sprintf("/v2/projects/%s/styleguides", project_id) data_hash = {} post_body = nil reqHelper = PhraseApp::RequestHelper.new(data_hash, post_body) rc, err = PhraseApp.send_request_paginated("GET", path, reqHelper.ctype, reqHelper.body, 200, page, per_page) if err != nil return nil, err end return JSON.load(rc.body).map { |item| PhraseApp::Styleguide.new(item) }, err end |
.styleguide_show(project_id, id) ⇒ Object
Get details on a single style guide.
1658 1659 1660 1661 1662 1663 1664 1665 1666 1667 1668 1669 1670 |
# File 'lib/phraseapp-ruby.rb', line 1658 def self.styleguide_show(project_id, id) path = sprintf("/v2/projects/%s/styleguides/%s", project_id, id) data_hash = {} post_body = nil reqHelper = PhraseApp::RequestHelper.new(data_hash, post_body) rc, err = PhraseApp.send_request("GET", path, reqHelper.ctype, reqHelper.body, 200) if err != nil return nil, err end return PhraseApp::StyleguideDetails.new(JSON.load(rc.body)), err end |
.styleguide_update(project_id, id, params) ⇒ Object
Update an existing style guide.
1673 1674 1675 1676 1677 1678 1679 1680 1681 1682 1683 1684 1685 1686 1687 1688 1689 1690 |
# File 'lib/phraseapp-ruby.rb', line 1673 def self.styleguide_update(project_id, id, params) path = sprintf("/v2/projects/%s/styleguides/%s", project_id, id) data_hash = {} post_body = nil data_hash = params.to_h err = params.validate if err != nil return nil, err end reqHelper = PhraseApp::RequestHelper.new(data_hash, post_body) rc, err = PhraseApp.send_request("PATCH", path, reqHelper.ctype, reqHelper.body, 200) if err != nil return nil, err end return PhraseApp::StyleguideDetails.new(JSON.load(rc.body)), err end |
.tag_create(project_id, params) ⇒ Object
Create a new tag.
1693 1694 1695 1696 1697 1698 1699 1700 1701 1702 1703 1704 1705 1706 1707 1708 1709 1710 |
# File 'lib/phraseapp-ruby.rb', line 1693 def self.tag_create(project_id, params) path = sprintf("/v2/projects/%s/tags", project_id) data_hash = {} post_body = nil data_hash = params.to_h err = params.validate if err != nil return nil, err end reqHelper = PhraseApp::RequestHelper.new(data_hash, post_body) rc, err = PhraseApp.send_request("POST", path, reqHelper.ctype, reqHelper.body, 201) if err != nil return nil, err end return PhraseApp::TagWithStats.new(JSON.load(rc.body)), err end |
.tag_delete(project_id, name) ⇒ Object
Delete an existing tag.
1713 1714 1715 1716 1717 1718 1719 1720 1721 1722 1723 1724 1725 |
# File 'lib/phraseapp-ruby.rb', line 1713 def self.tag_delete(project_id, name) path = sprintf("/v2/projects/%s/tags/%s", project_id, name) data_hash = {} post_body = nil reqHelper = PhraseApp::RequestHelper.new(data_hash, post_body) rc, err = PhraseApp.send_request("DELETE", path, reqHelper.ctype, reqHelper.body, 204) if err != nil return nil, err end return err end |
.tag_list(project_id, page, per_page) ⇒ Object
List all tags for the given project.
1728 1729 1730 1731 1732 1733 1734 1735 1736 1737 1738 1739 1740 |
# File 'lib/phraseapp-ruby.rb', line 1728 def self.tag_list(project_id, page, per_page) path = sprintf("/v2/projects/%s/tags", project_id) data_hash = {} post_body = nil reqHelper = PhraseApp::RequestHelper.new(data_hash, post_body) rc, err = PhraseApp.send_request_paginated("GET", path, reqHelper.ctype, reqHelper.body, 200, page, per_page) if err != nil return nil, err end return JSON.load(rc.body).map { |item| PhraseApp::Tag.new(item) }, err end |
.tag_show(project_id, name) ⇒ Object
Get details and progress information on a single tag for a given project.
1743 1744 1745 1746 1747 1748 1749 1750 1751 1752 1753 1754 1755 |
# File 'lib/phraseapp-ruby.rb', line 1743 def self.tag_show(project_id, name) path = sprintf("/v2/projects/%s/tags/%s", project_id, name) data_hash = {} post_body = nil reqHelper = PhraseApp::RequestHelper.new(data_hash, post_body) rc, err = PhraseApp.send_request("GET", path, reqHelper.ctype, reqHelper.body, 200) if err != nil return nil, err end return PhraseApp::TagWithStats.new(JSON.load(rc.body)), err end |
.translation_create(project_id, params) ⇒ Object
Create a translation.
1758 1759 1760 1761 1762 1763 1764 1765 1766 1767 1768 1769 1770 1771 1772 1773 1774 1775 |
# File 'lib/phraseapp-ruby.rb', line 1758 def self.translation_create(project_id, params) path = sprintf("/v2/projects/%s/translations", project_id) data_hash = {} post_body = nil data_hash = params.to_h err = params.validate if err != nil return nil, err end reqHelper = PhraseApp::RequestHelper.new(data_hash, post_body) rc, err = PhraseApp.send_request("POST", path, reqHelper.ctype, reqHelper.body, 201) if err != nil return nil, err end return PhraseApp::TranslationDetails.new(JSON.load(rc.body)), err end |
.translation_list_all(project_id, page, per_page, params) ⇒ Object
List translations for the given project.
1778 1779 1780 1781 1782 1783 1784 1785 1786 1787 1788 1789 1790 1791 1792 1793 1794 1795 |
# File 'lib/phraseapp-ruby.rb', line 1778 def self.translation_list_all(project_id, page, per_page, params) path = sprintf("/v2/projects/%s/translations", project_id) data_hash = {} post_body = nil data_hash = params.to_h err = params.validate if err != nil return nil, err end reqHelper = PhraseApp::RequestHelper.new(data_hash, post_body) rc, err = PhraseApp.send_request_paginated("GET", path, reqHelper.ctype, reqHelper.body, 200, page, per_page) if err != nil return nil, err end return JSON.load(rc.body).map { |item| PhraseApp::Translation.new(item) }, err end |
.translation_list_key(project_id, key_id, page, per_page, params) ⇒ Object
List translations for a specific key.
1798 1799 1800 1801 1802 1803 1804 1805 1806 1807 1808 1809 1810 1811 1812 1813 1814 1815 |
# File 'lib/phraseapp-ruby.rb', line 1798 def self.translation_list_key(project_id, key_id, page, per_page, params) path = sprintf("/v2/projects/%s/keys/%s/translations", project_id, key_id) data_hash = {} post_body = nil data_hash = params.to_h err = params.validate if err != nil return nil, err end reqHelper = PhraseApp::RequestHelper.new(data_hash, post_body) rc, err = PhraseApp.send_request_paginated("GET", path, reqHelper.ctype, reqHelper.body, 200, page, per_page) if err != nil return nil, err end return JSON.load(rc.body).map { |item| PhraseApp::Translation.new(item) }, err end |
.translation_list_locale(project_id, locale_id, page, per_page, params) ⇒ Object
List translations for a specific locale.
1818 1819 1820 1821 1822 1823 1824 1825 1826 1827 1828 1829 1830 1831 1832 1833 1834 1835 |
# File 'lib/phraseapp-ruby.rb', line 1818 def self.translation_list_locale(project_id, locale_id, page, per_page, params) path = sprintf("/v2/projects/%s/locales/%s/translations", project_id, locale_id) data_hash = {} post_body = nil data_hash = params.to_h err = params.validate if err != nil return nil, err end reqHelper = PhraseApp::RequestHelper.new(data_hash, post_body) rc, err = PhraseApp.send_request_paginated("GET", path, reqHelper.ctype, reqHelper.body, 200, page, per_page) if err != nil return nil, err end return JSON.load(rc.body).map { |item| PhraseApp::Translation.new(item) }, err end |
.translation_show(project_id, id) ⇒ Object
Get details on a single translation.
1838 1839 1840 1841 1842 1843 1844 1845 1846 1847 1848 1849 1850 |
# File 'lib/phraseapp-ruby.rb', line 1838 def self.translation_show(project_id, id) path = sprintf("/v2/projects/%s/translations/%s", project_id, id) data_hash = {} post_body = nil reqHelper = PhraseApp::RequestHelper.new(data_hash, post_body) rc, err = PhraseApp.send_request("GET", path, reqHelper.ctype, reqHelper.body, 200) if err != nil return nil, err end return PhraseApp::TranslationDetails.new(JSON.load(rc.body)), err end |
.translation_update(project_id, id, params) ⇒ Object
Update an existing translation.
1853 1854 1855 1856 1857 1858 1859 1860 1861 1862 1863 1864 1865 1866 1867 1868 1869 1870 |
# File 'lib/phraseapp-ruby.rb', line 1853 def self.translation_update(project_id, id, params) path = sprintf("/v2/projects/%s/translations/%s", project_id, id) data_hash = {} post_body = nil data_hash = params.to_h err = params.validate if err != nil return nil, err end reqHelper = PhraseApp::RequestHelper.new(data_hash, post_body) rc, err = PhraseApp.send_request("PATCH", path, reqHelper.ctype, reqHelper.body, 200) if err != nil return nil, err end return PhraseApp::TranslationDetails.new(JSON.load(rc.body)), err end |
.upload_create(project_id, params) ⇒ Object
Upload a new file to your project. This will extract all new content such as keys, translations, locales, tags etc. and store them in your project.
1873 1874 1875 1876 1877 1878 1879 1880 1881 1882 1883 1884 1885 1886 1887 1888 1889 1890 1891 1892 1893 1894 1895 1896 1897 1898 1899 1900 1901 1902 1903 1904 1905 1906 1907 1908 1909 1910 1911 1912 1913 1914 1915 1916 1917 1918 1919 1920 1921 1922 1923 1924 1925 1926 1927 1928 1929 1930 |
# File 'lib/phraseapp-ruby.rb', line 1873 def self.upload_create(project_id, params) path = sprintf("/v2/projects/%s/uploads", project_id) data_hash = {} post_body = nil if params.convert_emoji != nil data_hash["convert_emoji"] = (params.convert_emoji == "true") end if params.file != nil post_body = [] post_body << "--#{PhraseApp::MULTIPART_BOUNDARY}\r\n" post_body << "Content-Disposition: form-data; name=\"file\"; filename=\"#{File.basename(params.file )}\"\r\n" post_body << "Content-Type: text/plain\r\n" post_body << "\r\n" post_body << File.read(params.file) post_body << "\r\n" end if params.format != nil data_hash["format"] = params.format end if params. != nil params..each do |key, value| data_hash["format_options"][key] = value end end if params.locale_id != nil data_hash["locale_id"] = params.locale_id end if params.skip_unverification != nil data_hash["skip_unverification"] = (params.skip_unverification == "true") end if params. != nil data_hash["skip_upload_tags"] = (params. == "true") end if params. != nil data_hash["tags"] = params. end if params.update_translations != nil data_hash["update_translations"] = (params.update_translations == "true") end reqHelper = PhraseApp::RequestHelper.new(data_hash, post_body) rc, err = PhraseApp.send_request("POST", path, reqHelper.ctype, reqHelper.body, 201) if err != nil return nil, err end return PhraseApp::LocaleFileImportWithSummary.new(JSON.load(rc.body)), err end |
.upload_show(project_id, id) ⇒ Object
View details and summary for a single upload.
1933 1934 1935 1936 1937 1938 1939 1940 1941 1942 1943 1944 1945 |
# File 'lib/phraseapp-ruby.rb', line 1933 def self.upload_show(project_id, id) path = sprintf("/v2/projects/%s/uploads/%s", project_id, id) data_hash = {} post_body = nil reqHelper = PhraseApp::RequestHelper.new(data_hash, post_body) rc, err = PhraseApp.send_request("GET", path, reqHelper.ctype, reqHelper.body, 200) if err != nil return nil, err end return PhraseApp::LocaleFileImportWithSummary.new(JSON.load(rc.body)), err end |
.version_list(project_id, translation_id, page, per_page) ⇒ Object
List all versions for the given translation.
1948 1949 1950 1951 1952 1953 1954 1955 1956 1957 1958 1959 1960 |
# File 'lib/phraseapp-ruby.rb', line 1948 def self.version_list(project_id, translation_id, page, per_page) path = sprintf("/v2/projects/%s/translations/%s/versions", project_id, translation_id) data_hash = {} post_body = nil reqHelper = PhraseApp::RequestHelper.new(data_hash, post_body) rc, err = PhraseApp.send_request_paginated("GET", path, reqHelper.ctype, reqHelper.body, 200, page, per_page) if err != nil return nil, err end return JSON.load(rc.body).map { |item| PhraseApp::TranslationVersion.new(item) }, err end |
.version_show(project_id, translation_id, id) ⇒ Object
Get details on a single version.
1963 1964 1965 1966 1967 1968 1969 1970 1971 1972 1973 1974 1975 |
# File 'lib/phraseapp-ruby.rb', line 1963 def self.version_show(project_id, translation_id, id) path = sprintf("/v2/projects/%s/translations/%s/versions/%s", project_id, translation_id, id) data_hash = {} post_body = nil reqHelper = PhraseApp::RequestHelper.new(data_hash, post_body) rc, err = PhraseApp.send_request("GET", path, reqHelper.ctype, reqHelper.body, 200) if err != nil return nil, err end return PhraseApp::TranslationVersionWithUser.new(JSON.load(rc.body)), err end |