Class: PhraseApp::RequestParams::ScreenshotMarkerParams

Inherits:
OpenStruct
  • Object
show all
Defined in:
lib/phraseapp-ruby.rb

Overview

ScreenshotMarkerParams

Parameters:

key_id

Specify the Key ID which should be highlighted on the specified screenshot. The Key must belong to the project.

presentation

Presentation details of the screenshot marker in JSON format.

Each Screenshot Marker is represented as a rectangular shaped highlight box with the name of the specified Key attached. You can specify the marker position on the screenshot (x-axis and y-axis in pixels) from the top left corner of the screenshot and the dimensions of the marker itself (w and h in pixels).

Instance Method Summary collapse

Instance Method Details

#key_id=(val) ⇒ Object



1359
1360
1361
# File 'lib/phraseapp-ruby.rb', line 1359

def key_id=(val)
  super(val)
end

#presentation=(val) ⇒ Object



1363
1364
1365
# File 'lib/phraseapp-ruby.rb', line 1363

def presentation=(val)
  super(val)
end

#validateObject



1367
1368
1369
1370
1371
1372
1373
1374
1375
# File 'lib/phraseapp-ruby.rb', line 1367

def validate
  
  if key_id == nil
    raise PhraseApp::ParamsHelpers::ParamsValidationError.new("Required parameter \"key_id\" of \"ScreenshotMarkerParams\" not set")
  end
  if presentation == nil || presentation == "" 
    raise PhraseApp::ParamsHelpers::ParamsValidationError.new("Required parameter \"presentation\" of \"ScreenshotMarkerParams\" not set")
  end
end